# API Documentation of Bash Range Expand Library

## error messages

### error-codes

```
error-codes (bash-csv)
# <50 .. reserved for base-base error-codes
#  51 .. illegal handle-name
#  52 .. handle not loaded
#  53 .. handle already in use
#  9x .. errors local to each function
```

## range expansion

### ranges

```
ranges
# a range consist of one or more separated by separator
#  + <aliase> (^[[:alpha:]][[:alnum:]_]*$) references another range
#  + <name> (^[[:alpha:]][[:alnum:]_]*$) expands to itself
#  + <number> expands to <prefix><number><suffix>
#  * <number>-<higher_number> expands to all numbers in that range
# a separator must not contain the following chars: [[:alnum:]_]
# default separator is space (' ')
# each alias can set its own prefix and suffix
# if none is defined in an alias the globally set prefix and suffix will be used
# default prefix and suffix is ""
```

## range expand

### bre_expand

```
bre_expand <ret-array-vn> <handle> <range> [..]
# expand ranges found in loaded handle and return it in ret-array
# range-dict keys are names of ranges (whitespace not allowed)
#   and their values can be:
#     a macro: any text string that matches a key of range-dict
#              its value will be expanded in recursive fashion
#     a range (<number>-<number>): will be expanded to each member of range
#                                  prefix and suffix will be added to each
#     a number: prefix and suffix will be added
#     any other string will be copied unmodified
# errors: 2, 3, 91 (illegal range), 92 (reffered alias not found),
#         93 (ref loop detected), 94 (multiple errors happened)
```

### bre_expand

```
bre_expand <ret-array-vn> <handle> <range> [..]
# works like bre_expand but stop after one expansion, no recursion
# errors: 2, 3, 91 (illegal range), 92 (reffered alias not found),
#         93 (ref loop detected), 94 (multiple errors happened)
```

## handle helpers

### bre_handle_is_loaded

```
bre_handle_is_loaded <handle>
# check if handle is open
# errors: 2, 51, 52
```

### bre_handle_create_empty

```
bre_handle_create_empty <handle>
# create an empty handle
# errors: 1, 2, 51, 52
```

### bre_handle_create_from_ini

```
bre_handle_create_from_ini <handle> <path>
# errors: 51, 52, 53, 91 (failed to load ini from path), 92 (bash-ini error)
# shellcheck disable=SC2178
```

### bre_discard

```
bre_discard <handle>
# discard a handle
# errors: 51, 52
```
